@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2024 Roberto Alsina and others.
+# Copyright © 2012-2025 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -27,14 +27,19 @@
 """Nikola -- a modular, fast, simple, static website generator."""
 
 import os
-import sys
 
-__version__ = '8.3.0'
+# The current Nikola version:
+__version__ = '8.3.3'
+
+# A flag whether logging should emit debug information:
 DEBUG = bool(os.getenv('NIKOLA_DEBUG'))
-SHOW_TRACEBACKS = bool(os.getenv('NIKOLA_SHOW_TRACEBACKS'))
 
-if sys.version_info[0] == 2:
-    raise Exception("Nikola does not support Python 2.")
+# A flag whether special templates trace logging should be generated:
+TEMPLATES_TRACE = bool(os.getenv('NIKOLA_TEMPLATES_TRACE'))
+
+# A flag to show tracebacks of unhandled exceptions.
+# This is a less noisy alternative to the NIKOLA_DEBUG flag.
+SHOW_TRACEBACKS = bool(os.getenv('NIKOLA_SHOW_TRACEBACKS'))
 
 from .nikola import Nikola  # NOQA
 from . import plugins  # NOQA
