@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2024 Roberto Alsina and others.
+# Copyright © 2012-2025 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -70,6 +70,7 @@ def apply_to_binary_file(f):
     a function that takes a filename and applies f to the contents,
     in place.  Reads files in binary mode.
     """
+
     @wraps(f)
     def f_in_file(fname, *args, **kwargs):
         with open(fname, 'rb') as inf:
@@ -88,6 +89,7 @@ def apply_to_text_file(f):
     a function that takes a filename and applies f to the contents,
     in place.  Reads files in UTF-8.
     """
+
     @wraps(f)
     def f_in_file(fname, *args, **kwargs):
         with io.open(fname, 'r', encoding='utf-8-sig') as inf:
@@ -126,14 +128,14 @@ def runinplace(command, infile):
 
     tmpdir = None
 
-    if "%2" in command:
-        tmpdir = tempfile.mkdtemp(prefix="nikola")
+    if '%2' in command:
+        tmpdir = tempfile.mkdtemp(prefix='nikola')
         tmpfname = os.path.join(tmpdir, os.path.basename(infile))
 
     try:
-        list_replace(command, "%1", infile)
+        list_replace(command, '%1', infile)
         if tmpdir:
-            list_replace(command, "%2", tmpfname)
+            list_replace(command, '%2', tmpfname)
 
         subprocess.check_call(command)
 
@@ -150,16 +152,20 @@ def yui_compressor(infile, executable=None):
     yuicompressor = executable
     if not yuicompressor:
         try:
-            subprocess.call('yui-compressor', stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+            subprocess.call(
+                'yui-compressor', stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL
+            )
             yuicompressor = 'yui-compressor'
         except Exception:
             pass
     if not yuicompressor:
         try:
-            subprocess.call('yuicompressor', stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
+            subprocess.call(
+                'yuicompressor', stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL
+            )
             yuicompressor = 'yuicompressor'
         except Exception:
-            raise Exception("yui-compressor is not installed.")
+            raise Exception('yui-compressor is not installed.')
             return False
 
     return runinplace('{} --nomunge %1 -o %2'.format(yuicompressor), infile)
@@ -168,62 +174,87 @@ def yui_compressor(infile, executable=None):
 @_ConfigurableFilter(executable='CLOSURE_COMPILER_EXECUTABLE')
 def closure_compiler(infile, executable='closure-compiler'):
     """Run closure-compiler on a file."""
-    return runinplace('{} --warning_level QUIET --js %1 --js_output_file %2'.format(executable), infile)
+    return runinplace(
+        '{} --warning_level QUIET --js %1 --js_output_file %2'.format(executable),
+        infile,
+    )
 
 
 @_ConfigurableFilter(executable='OPTIPNG_EXECUTABLE')
 def optipng(infile, executable='optipng'):
     """Run optipng on a file."""
-    return runinplace("{} -preserve -o2 -quiet %1".format(executable), infile)
+    return runinplace('{} -preserve -o2 -quiet %1'.format(executable), infile)
 
 
 @_ConfigurableFilter(executable='JPEGOPTIM_EXECUTABLE')
 def jpegoptim(infile, executable='jpegoptim'):
     """Run jpegoptim on a file."""
-    return runinplace("{} -p --strip-all -q %1".format(executable), infile)
+    return runinplace('{} -p --strip-all -q %1'.format(executable), infile)
 
 
 @_ConfigurableFilter(executable='JPEGOPTIM_EXECUTABLE')
 def jpegoptim_progressive(infile, executable='jpegoptim'):
     """Run jpegoptim on a file and convert to progressive."""
-    return runinplace("{} -p --strip-all --all-progressive -q %1".format(executable), infile)
+    return runinplace(
+        '{} -p --strip-all --all-progressive -q %1'.format(executable), infile
+    )
 
 
 @_ConfigurableFilter(executable='HTML_TIDY_EXECUTABLE')
-def html_tidy_withconfig(infile, executable='tidy5'):
-    """Run HTML Tidy with tidy5.conf as config file."""
-    return _html_tidy_runner(infile, "-quiet --show-info no --show-warnings no -utf8 -indent -config tidy5.conf -modify %1", executable=executable)
+def html_tidy_withconfig(infile, executable='tidy'):
+    """Run HTML Tidy with tidy.conf as config file."""
+    return _html_tidy_runner(
+        infile,
+        '-quiet --show-info no --show-warnings no -utf8 -indent -config tidy.conf -modify %1',
+        executable=executable,
+    )
 
 
 @_ConfigurableFilter(executable='HTML_TIDY_EXECUTABLE')
-def html_tidy_nowrap(infile, executable='tidy5'):
+def html_tidy_nowrap(infile, executable='tidy'):
     """Run HTML Tidy without line wrapping."""
-    return _html_tidy_runner(infile, "-quiet --show-info no --show-warnings no -utf8 -indent --indent-attributes no --sort-attributes alpha --wrap 0 --wrap-sections no --drop-empty-elements no --tidy-mark no -modify %1", executable=executable)
+    return _html_tidy_runner(
+        infile,
+        '-quiet --show-info no --show-warnings no -utf8 -indent --indent-attributes no --sort-attributes alpha --wrap 0 --wrap-sections no --drop-empty-elements no --tidy-mark no -modify %1',
+        executable=executable,
+    )
 
 
 @_ConfigurableFilter(executable='HTML_TIDY_EXECUTABLE')
-def html_tidy_wrap(infile, executable='tidy5'):
+def html_tidy_wrap(infile, executable='tidy'):
     """Run HTML Tidy with line wrapping."""
-    return _html_tidy_runner(infile, "-quiet --show-info no --show-warnings no -utf8 -indent --indent-attributes no --sort-attributes alpha --wrap 80 --wrap-sections no --drop-empty-elements no --tidy-mark no -modify %1", executable=executable)
+    return _html_tidy_runner(
+        infile,
+        '-quiet --show-info no --show-warnings no -utf8 -indent --indent-attributes no --sort-attributes alpha --wrap 80 --wrap-sections no --drop-empty-elements no --tidy-mark no -modify %1',
+        executable=executable,
+    )
 
 
 @_ConfigurableFilter(executable='HTML_TIDY_EXECUTABLE')
-def html_tidy_wrap_attr(infile, executable='tidy5'):
+def html_tidy_wrap_attr(infile, executable='tidy'):
     """Run HTML tidy with line wrapping and attribute indentation."""
-    return _html_tidy_runner(infile, "-quiet --show-info no --show-warnings no -utf8 -indent --indent-attributes yes --sort-attributes alpha --wrap 80 --wrap-sections no --drop-empty-elements no --tidy-mark no -modify %1", executable=executable)
+    return _html_tidy_runner(
+        infile,
+        '-quiet --show-info no --show-warnings no -utf8 -indent --indent-attributes yes --sort-attributes alpha --wrap 80 --wrap-sections no --drop-empty-elements no --tidy-mark no -modify %1',
+        executable=executable,
+    )
 
 
 @_ConfigurableFilter(executable='HTML_TIDY_EXECUTABLE')
-def html_tidy_mini(infile, executable='tidy5'):
+def html_tidy_mini(infile, executable='tidy'):
     """Run HTML tidy with minimal settings."""
-    return _html_tidy_runner(infile, "-quiet --show-info no --show-warnings no -utf8 --indent-attributes no --sort-attributes alpha --wrap 0 --wrap-sections no --tidy-mark no --drop-empty-elements no -modify %1", executable=executable)
+    return _html_tidy_runner(
+        infile,
+        '-quiet --show-info no --show-warnings no -utf8 --indent-attributes no --sort-attributes alpha --wrap 0 --wrap-sections no --tidy-mark no --drop-empty-elements no -modify %1',
+        executable=executable,
+    )
 
 
-def _html_tidy_runner(infile, options, executable='tidy5'):
+def _html_tidy_runner(infile, options, executable='tidy'):
     """Run HTML Tidy."""
     # Warnings (returncode 1) are not critical, and *everything* is a warning.
     try:
-        status = runinplace(executable + " " + options, infile)
+        status = runinplace(executable + ' ' + options, infile)
     except subprocess.CalledProcessError as err:
         status = 0 if err.returncode == 1 else err.returncode
     return status
@@ -234,14 +265,17 @@ def html5lib_minify(data):
     """Minify with html5lib."""
     import html5lib
     import html5lib.serializer
-    data = html5lib.serializer.serialize(html5lib.parse(data, treebuilder='lxml'),
-                                         tree='lxml',
-                                         quote_attr_values='spec',
-                                         omit_optional_tags=True,
-                                         minimize_boolean_attributes=True,
-                                         strip_whitespace=True,
-                                         alphabetical_attributes=True,
-                                         escape_lt_in_attrs=True)
+
+    data = html5lib.serializer.serialize(
+        html5lib.parse(data, treebuilder='lxml'),
+        tree='lxml',
+        quote_attr_values='spec',
+        omit_optional_tags=True,
+        minimize_boolean_attributes=True,
+        strip_whitespace=True,
+        alphabetical_attributes=True,
+        escape_lt_in_attrs=True,
+    )
     return data
 
 
@@ -250,13 +284,16 @@ def html5lib_xmllike(data):
     """Transform document to an XML-like form with html5lib."""
     import html5lib
     import html5lib.serializer
-    data = html5lib.serializer.serialize(html5lib.parse(data, treebuilder='lxml'),
-                                         tree='lxml',
-                                         quote_attr_values='always',
-                                         omit_optional_tags=False,
-                                         strip_whitespace=False,
-                                         alphabetical_attributes=True,
-                                         escape_lt_in_attrs=True)
+
+    data = html5lib.serializer.serialize(
+        html5lib.parse(data, treebuilder='lxml'),
+        tree='lxml',
+        quote_attr_values='always',
+        omit_optional_tags=False,
+        strip_whitespace=False,
+        alphabetical_attributes=True,
+        escape_lt_in_attrs=True,
+    )
     return data
 
 
@@ -268,7 +305,7 @@ def minify_lines(data):
 
 def _run_typogrify(data, typogrify_filters, ignore_tags=None):
     """Run typogrify with ignore support."""
-    default_ignore_tags = ["title", ".math"]
+    default_ignore_tags = ['title', '.math']
     if ignore_tags is None:
         ignore_tags = default_ignore_tags
     else:
@@ -278,7 +315,7 @@ def _run_typogrify(data, typogrify_filters, ignore_tags=None):
 
     section_list = typo.process_ignores(data, ignore_tags)
 
-    rendered_text = ""
+    rendered_text = ''
     for text_item, should_process in section_list:
         if should_process:
             for f in typogrify_filters:
@@ -295,14 +332,18 @@ def typogrify(data):
     if typo is None:
         req_missing(['typogrify'], 'use the typogrify filter', optional=True)
         return data
-    return _run_typogrify(data, [typo.amp, typo.widont, typo.smartypants, typo.caps, typo.initial_quotes])
+    return _run_typogrify(
+        data, [typo.amp, typo.widont, typo.smartypants, typo.caps, typo.initial_quotes]
+    )
 
 
 def _smarty_oldschool(text):
     try:
         import smartypants
     except ImportError:
-        raise typo.TypogrifyError("Error in {% smartypants %} filter: The Python smartypants library isn't installed.")
+        raise typo.TypogrifyError(
+            "Error in {% smartypants %} filter: The Python smartypants library isn't installed."
+        )
     else:
         output = smartypants.convert_dashes_oldschool(text)
         return output
@@ -315,7 +356,17 @@ def typogrify_oldschool(data):
         req_missing(['typogrify'], 'use the typogrify_oldschool filter', optional=True)
         return data
 
-    return _run_typogrify(data, [typo.amp, typo.widont, _smarty_oldschool, typo.smartypants, typo.caps, typo.initial_quotes])
+    return _run_typogrify(
+        data,
+        [
+            typo.amp,
+            typo.widont,
+            _smarty_oldschool,
+            typo.smartypants,
+            typo.caps,
+            typo.initial_quotes,
+        ],
+    )
 
 
 @apply_to_text_file
@@ -327,7 +378,9 @@ def typogrify_sans_widont(data):
         req_missing(['typogrify'], 'use the typogrify_sans_widont filter')
         return data
 
-    return _run_typogrify(data, [typo.amp, typo.smartypants, typo.caps, typo.initial_quotes])
+    return _run_typogrify(
+        data, [typo.amp, typo.smartypants, typo.caps, typo.initial_quotes]
+    )
 
 
 @apply_to_text_file
@@ -337,19 +390,29 @@ def typogrify_custom(data, typogrify_filters=None, ignore_tags=None):
         req_missing(['typogrify'], 'use the typogrify filter', optional=True)
         return data
     if typogrify_filters is None:
-        typogrify_filters = [typo.amp, typo.widont, typo.smartypants, typo.caps, typo.initial_quotes]
+        typogrify_filters = [
+            typo.amp,
+            typo.widont,
+            typo.smartypants,
+            typo.caps,
+            typo.initial_quotes,
+        ]
     return _run_typogrify(data, typogrify_filters, ignore_tags)
 
 
 @apply_to_text_file
 def php_template_injection(data):
     """Insert PHP code into Nikola templates."""
-    template = re.search(r'<\!-- __NIKOLA_PHP_TEMPLATE_INJECTION source\:(.*) checksum\:(.*)__ -->', data)
+    template = re.search(
+        r'<\!-- __NIKOLA_PHP_TEMPLATE_INJECTION source\:(.*) checksum\:(.*)__ -->', data
+    )
     if template:
         source = template.group(1)
-        with io.open(source, "r", encoding="utf-8-sig") as in_file:
+        with io.open(source, 'r', encoding='utf-8-sig') as in_file:
             phpdata = in_file.read()
-        _META_SEPARATOR = '(' + os.linesep * 2 + '|' + ('\n' * 2) + '|' + ("\r\n" * 2) + ')'
+        _META_SEPARATOR = (
+            '(' + os.linesep * 2 + '|' + ('\n' * 2) + '|' + ('\r\n' * 2) + ')'
+        )
         phpdata = re.split(_META_SEPARATOR, phpdata, maxsplit=1)[-1]
         phpdata = data.replace(template.group(0), phpdata)
         return phpdata
@@ -365,7 +428,10 @@ def cssminify(data):
         _data = {'input': data}
         response = requests.post(url, data=_data)
         if response.status_code != 200:
-            LOGGER.error("Can't use toptal.com CSS Minifier: HTTP status {}", response.status_code)
+            LOGGER.error(
+                "Can't use toptal.com CSS Minifier: HTTP status {}",
+                response.status_code,
+            )
             return data
         return response.text
     except Exception as exc:
@@ -381,7 +447,10 @@ def jsminify(data):
         _data = {'input': data}
         response = requests.post(url, data=_data)
         if response.status_code != 200:
-            LOGGER.error("Can't use toptal.com JavaScript Minifier: HTTP status {}", response.status_code)
+            LOGGER.error(
+                "Can't use toptal.com JavaScript Minifier: HTTP status {}",
+                response.status_code,
+            )
             return data
         return response.text
     except Exception as exc:
@@ -401,7 +470,9 @@ def xmlminify(data):
     """Minify XML files (strip whitespace and use minimal separators)."""
     parser = lxml.etree.XMLParser(remove_blank_text=True)
     newdata = lxml.etree.XML(data, parser=parser)
-    return lxml.etree.tostring(newdata, encoding='utf-8', method='xml', xml_declaration=True)
+    return lxml.etree.tostring(
+        newdata, encoding='utf-8', method='xml', xml_declaration=True
+    )
 
 
 def _normalize_html(data):
@@ -417,7 +488,10 @@ def _normalize_html(data):
 normalize_html = apply_to_text_file(_normalize_html)
 
 
-@_ConfigurableFilter(xpath_list='HEADER_PERMALINKS_XPATH_LIST', file_blacklist='HEADER_PERMALINKS_FILE_BLACKLIST')
+@_ConfigurableFilter(
+    xpath_list='HEADER_PERMALINKS_XPATH_LIST',
+    file_blacklist='HEADER_PERMALINKS_FILE_BLACKLIST',
+)
 def add_header_permalinks(fname, xpath_list=None, file_blacklist=None):
     """Post-process HTML via lxml to add header permalinks Sphinx-style."""
     # Blacklist requires custom file handling
@@ -433,6 +507,7 @@ def add_header_permalinks(fname, xpath_list=None, file_blacklist=None):
     except KeyError:
         # Circular import workaround (utils imports filters)
         from nikola.utils import LocaleBorg
+
         lang = LocaleBorg().current_lang
 
     xpath_set = set()
@@ -456,11 +531,15 @@ def add_header_permalinks(fname, xpath_list=None, file_blacklist=None):
                 node.attrib['id'] = slugify(node.text_content(), lang, True)
                 hid = node.attrib['id']
 
-            new_node = lxml.html.fragment_fromstring('<a href="#{0}" class="headerlink" title="Permalink to this heading">¶</a>'.format(hid))
+            new_node = lxml.html.fragment_fromstring(
+                '<a href="#{0}" class="headerlink" title="Permalink to this heading">¶</a>'.format(
+                    hid
+                )
+            )
             node.append(new_node)
 
     with io.open(fname, 'w', encoding='utf-8') as outf:
-        outf.write('<!DOCTYPE html>\n' + lxml.html.tostring(doc, encoding="unicode"))
+        outf.write('<!DOCTYPE html>\n' + lxml.html.tostring(doc, encoding='unicode'))
 
 
 @_ConfigurableFilter(top_classes='DEDUPLICATE_IDS_TOP_CLASSES')
