@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2013-2023 Udo Spallek, Roberto Alsina and others.
+# Copyright © 2013-2025 Udo Spallek, Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -88,7 +88,7 @@ class PostListDirective(Directive):
         date = self.options.get('date')
         filename = self.state.document.settings._nikola_source_path
 
-        output, deps = self.site.plugin_manager.getPluginByName(
+        output, deps = self.site.plugin_manager.get_plugin_by_name(
             'post_list', 'ShortcodePlugin').plugin_object.handler(
                 start,
                 stop,
