@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2024 Roberto Alsina and others.
+# Copyright © 2012-2025 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -30,6 +30,8 @@ import configparser
 import datetime
 import hashlib
 import io
+import urllib
+
 import lxml.html
 import operator
 import os
@@ -40,16 +42,14 @@ import socket
 import subprocess
 import sys
 import threading
-import typing
 from collections import defaultdict, OrderedDict
-from collections.abc import Callable, Iterable
 from html import unescape as html_unescape
 from importlib import reload as _reload
 from unicodedata import normalize as unicodenormalize
 from urllib.parse import quote as urlquote
 from urllib.parse import unquote as urlunquote
 from urllib.parse import urlparse, urlunparse
-from zipfile import ZipFile as zipf
+from zipfile import ZipFile
 
 import babel.dates
 import dateutil.parser
@@ -60,17 +60,21 @@ import PyRSS2Gen as rss
 from blinker import signal
 from doit import tools
 from doit.cmdparse import CmdParse
-from pkg_resources import resource_filename
 from nikola.packages.pygments_better_html import BetterHtmlFormatter
-from typing import List
+from typing import Any, Callable, Dict, Iterable, List, Match, Optional, Union
 from unidecode import unidecode
 
 # Renames
 from nikola import DEBUG  # NOQA
-from .log import LOGGER, get_logger  # NOQA
+from .log import LOGGER, TEMPLATES_LOGGER, get_logger  # NOQA
 from .hierarchy_utils import TreeNode, clone_treenode, flatten_tree_structure, sort_classifications
 from .hierarchy_utils import join_hierarchical_category_path, parse_escaped_hierarchical_category_name
 
+if sys.version_info.minor <= 8:
+    from pkg_resources import resource_filename
+else:
+    from importlib import resources
+
 try:
     import toml
 except ImportError:
@@ -577,7 +581,15 @@ class config_changed(tools.config_changed):
                                                            sort_keys=True))
 
 
-def get_theme_path_real(theme, themes_dirs):
+def pkg_resources_path(package, resource):
+    """Return path to a resource from the package with the given name."""
+    if sys.version_info.minor <= 8:
+        return resource_filename(package, resource)
+    else:
+        return str(resources.files(package).joinpath(resource))
+
+
+def get_theme_path_real(theme, themes_dirs) -> str:
     """Return the path where the given theme's files are located.
 
     Looks in ./themes and in the place where themes go when installed.
@@ -586,7 +598,7 @@ def get_theme_path_real(theme, themes_dirs):
         dir_name = os.path.join(themes_dir, theme)
         if os.path.isdir(dir_name):
             return dir_name
-    dir_name = resource_filename('nikola', os.path.join('data', 'themes', theme))
+    dir_name = pkg_resources_path('nikola', os.path.join('data', 'themes', theme))
     if os.path.isdir(dir_name):
         return dir_name
     raise Exception("Can't find theme '{0}'".format(theme))
@@ -597,7 +609,7 @@ def get_theme_path(theme):
     return theme
 
 
-def parse_theme_meta(theme_dir):
+def parse_theme_meta(theme_dir) -> Optional[configparser.ConfigParser]:
     """Parse a .theme meta file."""
     cp = configparser.ConfigParser()
     # The `or` case is in case theme_dir ends with a trailing slash
@@ -607,7 +619,7 @@ def parse_theme_meta(theme_dir):
     return cp if cp.has_section('Theme') else None
 
 
-def get_template_engine(themes):
+def get_template_engine(themes) -> str:
     """Get template engine used by a given theme."""
     for theme_name in themes:
         meta = parse_theme_meta(theme_name)
@@ -625,7 +637,7 @@ def get_template_engine(themes):
     return 'mako'
 
 
-def get_parent_theme_name(theme_name, themes_dirs=None):
+def get_parent_theme_name(theme_name, themes_dirs=None) -> Optional[str]:
     """Get name of parent theme."""
     meta = parse_theme_meta(theme_name)
     if meta:
@@ -645,7 +657,7 @@ def get_parent_theme_name(theme_name, themes_dirs=None):
         return None
 
 
-def get_theme_chain(theme, themes_dirs):
+def get_theme_chain(theme, themes_dirs) -> List[str]:
     """Create the full theme inheritance chain including paths."""
     themes = [get_theme_path_real(theme, themes_dirs)]
 
@@ -904,20 +916,22 @@ def extract_all(zipfile, path='themes'):
     """Extract all files from a zip file."""
     pwd = os.getcwd()
     makedirs(path)
-    os.chdir(path)
-    z = zipf(zipfile)
-    namelist = z.namelist()
-    for f in namelist:
-        if f.endswith('/') and '..' in f:
-            raise UnsafeZipException('The zip file contains ".." and is '
-                                     'not safe to expand.')
-    for f in namelist:
-        if f.endswith('/'):
-            makedirs(f)
-        else:
-            z.extract(f)
-    z.close()
-    os.chdir(pwd)
+    try:
+        os.chdir(path)
+        z = ZipFile(zipfile)
+        namelist = z.namelist()
+        for f in namelist:
+            if f.endswith('/') and '..' in f:
+                raise UnsafeZipException('The zip file contains ".." and is '
+                                         'not safe to expand.')
+        for f in namelist:
+            if f.endswith('/'):
+                makedirs(f)
+            else:
+                z.extract(f)
+        z.close()
+    finally:
+        os.chdir(pwd)
 
 
 def to_datetime(value, tzinfo=None):
@@ -1183,7 +1197,7 @@ class LocaleBorg(object):
     in_string_formatter = None
 
     @classmethod
-    def initialize(cls, locales: 'typing.Dict[str, str]', initial_lang: str):
+    def initialize(cls, locales: Dict[str, str], initial_lang: str):
         """Initialize LocaleBorg.
 
         locales: dict with custom locale name overrides.
@@ -1236,8 +1250,8 @@ class LocaleBorg(object):
             return ''
 
     def formatted_date(self, date_format: 'str',
-                       date: 'typing.Union[datetime.date, datetime.datetime]',
-                       lang: 'typing.Optional[str]' = None) -> str:
+                       date: Union[datetime.date, datetime.datetime],
+                       lang: Optional[str] = None) -> str:
         """Return the formatted date/datetime as a string."""
         if lang is None:
             lang = self.current_lang
@@ -1256,7 +1270,7 @@ class LocaleBorg(object):
         else:
             return format_datetime(date, date_format, locale=locale)
 
-    def format_date_in_string(self, message: str, date: datetime.date, lang: 'typing.Optional[str]' = None) -> str:
+    def format_date_in_string(self, message: str, date: datetime.date, lang: Optional[str] = None) -> str:
         """Format date inside a string (message).
 
         Accepted modes: month, month_year, month_day_year.
@@ -1272,7 +1286,7 @@ class LocaleBorg(object):
             lang = self.current_lang
         locale = self.locales.get(lang, lang)
 
-        def date_formatter(match: typing.Match) -> str:
+        def date_formatter(match: Match) -> str:
             """Format a date as requested."""
             mode, custom_format = match.groups()
             if LocaleBorg.in_string_formatter is not None:
@@ -1848,7 +1862,7 @@ def color_hsl_adjust_hex(hexstr, adjust_h=None, adjust_s=None, adjust_l=None):
 
 
 def dns_sd(port, inet6):
-    """Optimistically publish a HTTP service to the local network over DNS-SD.
+    """Optimistically publish an HTTP service to the local network over DNS-SD.
 
     Works only on Linux/FreeBSD.  Requires the `avahi` and `dbus` modules (symlinks in virtualenvs)
     """
@@ -1926,8 +1940,8 @@ def sort_posts(posts, *keys):
     return posts
 
 
-def smartjoin(join_char: str, string_or_iterable) -> str:
-    """Join string_or_iterable with join_char if it is iterable; otherwise converts it to string.
+def smartjoin(join_char: str, string_or_iterable: Union[None, str, bytes, Iterable[Any]]) -> str:
+    """Join string_or_iterable with join_char if it is iterable; otherwise convert it to string.
 
     >>> smartjoin('; ', 'foo, bar')
     'foo, bar'
@@ -1937,7 +1951,7 @@ def smartjoin(join_char: str, string_or_iterable) -> str:
     'count to 42'
     """
     if isinstance(string_or_iterable, (str, bytes)):
-        return string_or_iterable
+        return str(string_or_iterable)
     elif isinstance(string_or_iterable, Iterable):
         return join_char.join([str(e) for e in string_or_iterable])
     else:
@@ -2154,3 +2168,14 @@ class ClassificationTranslationManager(object):
         args = {'translation_manager': self, 'site': site,
                 'posts_per_classification_per_language': posts_per_classification_per_language}
         signal('{}_translations_config'.format(basename.lower())).send(args)
+
+
+def base_path_from_siteuri(siteuri: str) -> str:
+    """Extract the path part from a URI such as site['SITE_URL'].
+
+    The path returned doesn't end with a "/". (If only "/" is intended, it is empty.)
+    """
+    path = urllib.parse.urlsplit(siteuri).path
+    if path.endswith("/"):
+        path = path[:-1]
+    return path
